@@ -5,7 +5,6 @@ import time
 import logging
 import decimal
 import sqlite3
-import tempfile
 import contextlib
 import threading
 import itertools
@@ -522,13 +521,15 @@ def get_file(
             ExpiresIn=3600,
         )
         return fastapi.responses.RedirectResponse(
-            url, headers={"Cache-Control": "max-age=3600"}
+            url, headers={"Cache-Control": "max-age=30"}
         )
     if filepath.startswith("http://") or filepath.startswith("https://"):
         return fastapi.responses.RedirectResponse(
-            filepath, headers={"Cache-Control": "max-age=3600"}
+            filepath, headers={"Cache-Control": "max-age=30"}
         )
-    return fastapi.responses.FileResponse(filepath)
+    return fastapi.responses.FileResponse(
+        filepath, headers={"Cache-Control": "max-age=0"}
+    )
 
 
 def update_label_group_with_label(
@@ -1185,53 +1186,65 @@ def launch_simple_app(host: str, port: int, project: web.Project):
     """Launch a simplified version of the QSL app."""
     user = web.User(name="Default User", id=1, isAdmin=True)
 
-    with tempfile.TemporaryDirectory() as tdir:
-        app = build_app()
-        engine = sa.create_engine(
-            f"sqlite:///{tdir}/qsl-labeling.db",
-            echo=False,
-            connect_args={"check_same_thread": False},
+    app = build_app()
+    engine = sa.create_engine(
+        "sqlite://",
+        echo=False,
+        connect_args={"check_same_thread": False},
+        poolclass=sa.pool.StaticPool,
+    )
+    orm.BaseModel.metadata.create_all(engine)
+    with build_session(engine) as session:
+        project_id = create_project(project=project, session=session).id
+        assert project_id is not None, "Did not get a project ID."
+        user = create_user(
+            new_user=web.User(name="Default User", isAdmin=True),
+            existing_user=web.User(name="Dummy User", isAdmin=True),
+            session=session,
         )
-        orm.BaseModel.metadata.create_all(engine)
-        with build_session(engine) as session:
-            project_id = create_project(project=project, session=session).id
-            assert project_id is not None, "Did not get a project ID."
-            user = create_user(
-                new_user=web.User(name="Default User", isAdmin=True),
-                existing_user=web.User(name="Dummy User", isAdmin=True),
+        if project.labels:
+            default_groups: typing.Dict[web.ImageLabels, typing.Any] = {}
+            no_defaults: typing.List[web.ExportedImageLabels] = []
+            filepath_to_user_labels: typing.Dict[str, web.ImageLabels] = {}
+            for image in project.labels:
+                if (
+                    image.defaultLabels is not None
+                    and image.defaultLabels not in default_groups
+                ):
+                    default_groups[image.defaultLabels] = {
+                        "defaults": image.defaultLabels,
+                        "images": [image],
+                    }
+                elif image.defaultLabels is not None:
+                    default_groups[image.defaultLabels]["images"].append(image)
+                else:
+                    no_defaults.append(image)
+                if not image.labels:
+                    continue
+                if image.labels:
+                    for labels in image.labels:
+                        if labels.userId != 1:
+                            raise ValueError(
+                                "For simple projects, only one user is supported."
+                            )
+                        filepath_to_user_labels[image.filepath] = labels.labels
+            # Create images without defaults.
+            filepath_to_id: typing.Dict[str, int] = {}
+            for saved in create_images(
+                group=web.ImageGroup(files=[image.filepath for image in no_defaults]),
+                project_id=project_id,
                 session=session,
-            )
-            if project.labels:
-                default_groups: typing.Dict[web.ImageLabels, typing.Any] = {}
-                no_defaults: typing.List[web.ExportedImageLabels] = []
-                filepath_to_user_labels: typing.Dict[str, web.ImageLabels] = {}
-                for image in project.labels:
-                    if (
-                        image.defaultLabels is not None
-                        and image.defaultLabels not in default_groups
-                    ):
-                        default_groups[image.defaultLabels] = {
-                            "defaults": image.defaultLabels,
-                            "images": [image],
-                        }
-                    elif image.defaultLabels is not None:
-                        default_groups[image.defaultLabels]["images"].append(image)
-                    else:
-                        no_defaults.append(image)
-                    if not image.labels:
-                        continue
-                    if image.labels:
-                        for labels in image.labels:
-                            if labels.userId != 1:
-                                raise ValueError(
-                                    "For simple projects, only one user is supported."
-                                )
-                            filepath_to_user_labels[image.filepath] = labels.labels
-                # Create images without defaults.
-                filepath_to_id: typing.Dict[str, int] = {}
+                user=user,
+            ):
+                assert saved.id is not None, "Failed to get an image ID."
+                filepath_to_id[saved.filepath] = saved.id
+
+            # Create images with defaults.
+            for defaultSet in default_groups.values():
                 for saved in create_images(
                     group=web.ImageGroup(
-                        files=[image.filepath for image in no_defaults]
+                        files=[image.filepath for image in defaultSet["images"]],
+                        defaults=defaultSet["defaults"],
                     ),
                     project_id=project_id,
                     session=session,
@@ -1240,45 +1253,31 @@ def launch_simple_app(host: str, port: int, project: web.Project):
                     assert saved.id is not None, "Failed to get an image ID."
                     filepath_to_id[saved.filepath] = saved.id
 
-                # Create images with defaults.
-                for defaultSet in default_groups.values():
-                    for saved in create_images(
-                        group=web.ImageGroup(
-                            files=[image.filepath for image in defaultSet["images"]],
-                            defaults=defaultSet["defaults"],
-                        ),
-                        project_id=project_id,
-                        session=session,
-                        user=user,
-                    ):
-                        assert saved.id is not None, "Failed to get an image ID."
-                        filepath_to_id[saved.filepath] = saved.id
-
-                # Set user labels.
-                for filepath, user_labels in filepath_to_user_labels.items():
-                    set_labels(
-                        project_id=project_id,
-                        image_id=filepath_to_id[filepath],
-                        labels=user_labels,
-                        user=user,
-                        session=session,
-                    )
-        app.middleware("http")(
-            add_clients(
-                engine=engine,
-            )
+            # Set user labels.
+            for filepath, user_labels in filepath_to_user_labels.items():
+                set_labels(
+                    project_id=project_id,
+                    image_id=filepath_to_id[filepath],
+                    labels=user_labels,
+                    user=user,
+                    session=session,
+                )
+    app.middleware("http")(
+        add_clients(
+            engine=engine,
         )
-        app.on_event("startup")(
-            lambda: app.add_middleware(
-                SessionMiddleware,
-                secret_key="not-a-secret",
-                session_cookie="qsl-session",
-            )
+    )
+    app.on_event("startup")(
+        lambda: app.add_middleware(
+            SessionMiddleware,
+            secret_key="not-a-secret",
+            session_cookie="qsl-session",
         )
-        app.middleware("http")(mock_user_middleware(user))
-        uvicorn.run(app, host=host, port=port)
-        with build_session(engine) as session:
-            return export_project(user=user, project_id=project_id, session=session)
+    )
+    app.middleware("http")(mock_user_middleware(user))
+    uvicorn.run(app, host=host, port=port)
+    with build_session(engine) as session:
+        return export_project(user=user, project_id=project_id, session=session)
 
 
 default_app = build_app()
